<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/compresseur?lang_cible=he
// ** ne pas modifier le fichier **

return [

	// I
	'info_compresseur_titre' => 'אופטימציה וכיווץ',
];
